@@ -22,7 +22,7 @@ class AttackWPS(Attack):
         self.null_pin = null_pin
 
     def run(self):
-        ''' Run all WPS-related attacks '''
+        """ Run all WPS-related attacks """
 
         # Drop out if user specified to not use Reaver/Bully
         if Configuration.use_pmkid_only:
@@ -34,21 +34,12 @@ class AttackWPS(Attack):
             return False
 
         if not Configuration.wps_pixie and self.pixie_dust:
-            Color.pl('\r{!} {O}--no-pixie{R} was given, ignoring WPS Pixie-Dust Attack ' +
-                    'on {O}%s{W}' % self.target.essid)
+            Color.pl('\r{!} {O}--no-pixie{R} was given, ignoring WPS Pixie-Dust Attack on {O}%s{W}' % self.target.essid)
             self.success = False
             return False
 
-        if not Configuration.wps_pixie and self.pixie_dust: # kimocoder: STRING MÅ BYTTES
-            Color.pl('\r{!} {O}--no-nullpin{R} was given, ignoring WPS NULL PIN Attack ' +
-                    'on {O}%s{W}' % self.target.essid)
-            self.success = False
-            return False
-
-
         if not Configuration.wps_pin and not self.pixie_dust:
-            Color.pl('\r{!} {O}--pixie{R} was given, ignoring WPS PIN Attack on ' +
-                    '{O}%s{W}' % self.target.essid)
+            Color.pl('\r{!} {O}--pixie{R} was given, ignoring WPS PIN Attack on {O}%s{W}' % self.target.essid)
             self.success = False
             return False
 
