@@ -4,7 +4,6 @@
 from ..util.process import Process
 from ..util.color import Color
 from ..tools.tshark import Tshark
-from ..tools.pyrit import Pyrit
 
 import re
 import os
@@ -18,28 +17,25 @@ class Handshake(object):
         self.essid = essid
 
     def divine_bssid_and_essid(self):
-        '''
+        """
             Tries to find BSSID and ESSID from cap file.
             Sets this instances 'bssid' and 'essid' instance fields.
-        '''
+        """
 
         # We can get BSSID from the .cap filename if Wifite captured it.
         # ESSID is stripped of non-printable characters, so we can't rely on that.
         if self.bssid is None:
-            hs_regex = re.compile(r'^.*handshake_\w+_([0-9A-F\-]{17})_.*\.cap$', re.IGNORECASE)
-            match = hs_regex.match(self.capfile)
-            if match:
-                self.bssid = match.group(1).replace('-', ':')
+            hs_regex = re.compile(r'^.*handshake_\w+_([\dA-F\-]{17})_.*\.cap$', re.IGNORECASE)
+            result = hs_regex.match(self.capfile)
+            if result is not None:
+                self.bssid = result[1].replace('-', ':')
 
         # Get list of bssid/essid pairs from cap file
         pairs = Tshark.bssid_essid_pairs(self.capfile, bssid=self.bssid)
 
-        if len(pairs) == 0:
-            pairs = self.pyrit_handshakes()  # Find bssid/essid pairs that have handshakes in Pyrit
-
-        if len(pairs) == 0 and not self.bssid and not self.essid:
-            # Tshark and Pyrit failed us, nothing else we can do.
-            raise ValueError('Cannot find BSSID or ESSID in cap file %s' % self.capfile)
+        if len(pairs) == 0 and (not self.bssid and not self.essid):
+            # Tshark failed us, nothing else we can do.
+            raise ValueError(f'Cannot find BSSID or ESSID in cap file {self.capfile}')
 
         if not self.essid and not self.bssid:
             # We do not know the bssid nor the essid
@@ -48,30 +44,31 @@ class Handshake(object):
             self.bssid = pairs[0][0]
             self.essid = pairs[0][1]
             Color.pl('{!} {O}Warning{W}: {O}Arbitrarily selected ' +
-                    '{R}bssid{O} {C}%s{O} and {R}essid{O} "{C}%s{O}"{W}' % (self.bssid, self.essid))
+                     '{R}bssid{O} {C}%s{O} and {R}essid{O} "{C}%s{O}"{W}' % (self.bssid, self.essid))
 
-        elif not self.bssid:
+        if not self.bssid:
             # We already know essid
             for (bssid, essid) in pairs:
                 if self.essid == essid:
-                    Color.pl('{+} Discovered bssid {C}%s{W}' % bssid)
+                    Color.pl('\n{+} Discovered bssid {C}%s{W}' % bssid)
                     self.bssid = bssid
                     break
 
-        elif not self.essid:
+        if not self.essid:
             # We already know bssid
-            for (bssid, essid) in pairs:
-                if self.bssid.lower() == bssid.lower():
-                    Color.pl('{+} Discovered essid "{C}%s{W}"' % essid)
-                    self.essid = essid
-                    break
+            if len(pairs) > 0:
+                for (bssid, essid) in pairs:
+                    if self.bssid.lower() == bssid.lower():
+                        Color.pl('\n{+} Discovered essid "{C}%s{W}"' % essid)
+                        self.essid = essid
+                        break
 
     def has_handshake(self):
         if not self.bssid or not self.essid:
             self.divine_bssid_and_essid()
 
-        if len(self.tshark_handshakes()) > 0: return True
-        if len(self.pyrit_handshakes()) > 0: return True
+        if len(self.tshark_handshakes()) > 0:
+            return True
 
         # TODO: Can we trust cowpatty & aircrack?
         # if len(self.cowpatty_handshakes()) > 0: return True
@@ -80,74 +77,71 @@ class Handshake(object):
         return False
 
     def tshark_handshakes(self):
-        '''Returns list[tuple] of BSSID & ESSID pairs (ESSIDs are always `None`).'''
+        """Returns list[tuple] of BSSID & ESSID pairs (ESSIDs are always `None`)."""
         tshark_bssids = Tshark.bssids_with_handshakes(self.capfile, bssid=self.bssid)
         return [(bssid, None) for bssid in tshark_bssids]
 
     def cowpatty_handshakes(self):
-        '''Returns list[tuple] of BSSID & ESSID pairs (BSSIDs are always `None`).'''
+        """Returns list[tuple] of BSSID & ESSID pairs (BSSIDs are always `None`)."""
         if not Process.exists('cowpatty'):
             return []
-        if not self.essid:
-            return []  # We need a essid for cowpatty :(
+
+        # Needs to check if cowpatty is updated and have the -2 parameter
+        cowpattycheck = Process('cowpatty', devnull=False)
 
         command = [
             'cowpatty',
-            '-r', self.capfile,
-            '-s', self.essid,
-            '-c'  # Check for handshake
+            '-2' if 'frames 1 and 2 or 2 and 3 for key attack' in cowpattycheck.stdout() else '',   # Don't ignore incomplete handshakes
+            '-r',   self.capfile,
+            '-c'    # Check for handshake
         ]
 
         proc = Process(command, devnull=False)
-        for line in proc.stdout().split('\n'):
-            if 'Collected all necessary data to mount crack against WPA' in line:
-                return [(None, self.essid)]
-        return []
+        result = next(([(None, self.essid)] for line in proc.stdout().split('\n') if 'Collected all necessary data to mount crack against WPA' in line), [])
 
-    def pyrit_handshakes(self):
-        '''Returns list[tuple] of BSSID & ESSID pairs.'''
-        return Pyrit.bssid_essid_with_handshakes(
-                self.capfile, bssid=self.bssid, essid=self.essid)
+        return result
 
     def aircrack_handshakes(self):
-        '''Returns tuple (BSSID,None) if aircrack thinks self.capfile contains a handshake / can be cracked'''
+        """Returns tuple (BSSID,None) if aircrack thinks self.capfile contains a handshake / can be cracked"""
         if not self.bssid:
             return []  # Aircrack requires BSSID
 
-        command = 'echo "" | aircrack-ng -a 2 -w - -b %s "%s"' % (self.bssid, self.capfile)
-        (stdout, stderr) = Process.call(command)
+        command = [
+            'aircrack-ng',
+            '-b', self.bssid,
+            self.capfile
+        ]
 
-        if 'passphrase not in dictionary' in stdout.lower() or 'key not found' in stdout.lower():
+        proc = Process(command, devnull=False)
+
+        if 'potential target' in proc.stdout().lower() and 'no matching network' not in proc.stdout().lower():
             return [(self.bssid, None)]
         else:
             return []
 
     def analyze(self):
-        '''Prints analysis of handshake capfile'''
+        """Prints analysis of handshake capfile"""
         self.divine_bssid_and_essid()
 
         if Tshark.exists():
-            Handshake.print_pairs(self.tshark_handshakes(),   self.capfile, 'tshark')
-
-        if Pyrit.exists():
-            Handshake.print_pairs(self.pyrit_handshakes(),    self.capfile, 'pyrit')
+            Handshake.print_pairs(self.tshark_handshakes(), 'tshark')
 
         if Process.exists('cowpatty'):
-            Handshake.print_pairs(self.cowpatty_handshakes(), self.capfile, 'cowpatty')
+            Handshake.print_pairs(self.cowpatty_handshakes(), 'cowpatty')
 
-        Handshake.print_pairs(self.aircrack_handshakes(), self.capfile, 'aircrack')
+        Handshake.print_pairs(self.aircrack_handshakes(), 'aircrack')
 
     def strip(self, outfile=None):
         # XXX: This method might break aircrack-ng, use at own risk.
-        '''
+        """
             Strips out packets from handshake that aren't necessary to crack.
             Leaves only handshake packets and SSID broadcast (for discovery).
             Args:
                 outfile - Filename to save stripped handshake to.
                           If outfile==None, overwrite existing self.capfile.
-        '''
+        """
         if not outfile:
-            outfile = self.capfile + '.temp'
+            outfile = f'{self.capfile}.temp'
             replace_existing_file = True
         else:
             replace_existing_file = False
@@ -164,41 +158,37 @@ class Handshake(object):
             from shutil import copy
             copy(outfile, self.capfile)
             os.remove(outfile)
-            pass
 
     @staticmethod
-    def print_pairs(pairs, capfile, tool=None):
-        '''
+    def print_pairs(pairs, tool=None):
+        """
             Prints out BSSID and/or ESSID given a list of tuples (bssid,essid)
-        '''
-        tool_str = ''
-        if tool is not None:
-            tool_str = '{C}%s{W}: ' % tool.rjust(8)
-
+        """
+        tool_str = '{C}%s{W}: ' % tool.rjust(8) if tool is not None else ''
         if len(pairs) == 0:
-            Color.pl('{!} %s.cap file {R}does not{O} contain a valid handshake{W}' % (tool_str))
+            Color.pl('{!} %s.cap file {R}does not{O} contain a valid handshake{W}' % tool_str)
             return
 
         for (bssid, essid) in pairs:
             out_str = '{+} %s.cap file {G}contains a valid handshake{W} for' % tool_str
             if bssid and essid:
-                Color.pl('%s {G}%s{W} ({G}%s{W})' % (out_str, bssid, essid))
+                Color.pl('%s ({G}%s{W}) [{G}%s{W}]' % (out_str, bssid, essid))
             elif bssid:
-                Color.pl('%s {G}%s{W}' % (out_str, bssid))
+                Color.pl('%s ({G}%s{W})' % (out_str, bssid))
             elif essid:
-                Color.pl('%s ({G}%s{W})' % (out_str, essid))
+                Color.pl('%s [{G}%s{W}]' % (out_str, essid))
 
     @staticmethod
     def check():
-        ''' Analyzes .cap file(s) for handshake '''
+        """ Analyzes .cap file(s) for handshake """
         from ..config import Configuration
         if Configuration.check_handshake == '<all>':
             Color.pl('{+} checking all handshakes in {G}"./hs"{W} directory\n')
             try:
                 capfiles = [os.path.join('hs', x) for x in os.listdir('hs') if x.endswith('.cap')]
-            except OSError as e:
+            except OSError:
                 capfiles = []
-            if len(capfiles) == 0:
+            if not capfiles:
                 Color.pl('{!} {R}no .cap files found in {O}"./hs"{W}\n')
         else:
             capfiles = [Configuration.check_handshake]
@@ -214,25 +204,29 @@ class Handshake(object):
 
 
 if __name__ == '__main__':
+    print("\n-------------------------------")
     print('With BSSID & ESSID specified:')
     hs = Handshake('./tests/files/handshake_has_1234.cap', bssid='18:d6:c7:6d:6b:18', essid='YZWifi')
     hs.analyze()
-    print('has_hanshake() =', hs.has_handshake())
+    print(('has_hanshake() =', hs.has_handshake()))
 
+    print("\n-------------------------------")
     print('\nWith BSSID, but no ESSID specified:')
     hs = Handshake('./tests/files/handshake_has_1234.cap', bssid='18:d6:c7:6d:6b:18')
     hs.analyze()
-    print('has_hanshake() =', hs.has_handshake())
+    print(('has_hanshake() =', hs.has_handshake()))
 
+    print("\n-------------------------------")
     print('\nWith ESSID, but no BSSID specified:')
     hs = Handshake('./tests/files/handshake_has_1234.cap', essid='YZWifi')
     hs.analyze()
-    print('has_hanshake() =', hs.has_handshake())
+    print(('has_hanshake() =', hs.has_handshake()))
 
+    print("\n-------------------------------")
     print('\nWith neither BSSID nor ESSID specified:')
     hs = Handshake('./tests/files/handshake_has_1234.cap')
     try:
         hs.analyze()
-        print('has_hanshake() =', hs.has_handshake())
+        print(('has_hanshake() =', hs.has_handshake()))
     except Exception as e:
         Color.pl('{O}Error during Handshake.analyze(): {R}%s{W}' % e)
