@@ -8,13 +8,14 @@ import re
 
 
 class WPSState:
-    NONE, UNLOCKED, LOCKED, UNKNOWN = range(0, 4)
+    NONE, UNLOCKED, LOCKED, UNKNOWN = list(range(4))
 
 
 class ArchivedTarget(object):
-    '''
+    """
         Holds information between scans from a previously found target
-    '''
+    """
+
     def __init__(self, target):
         self.bssid = target.bssid
         self.channel = target.channel
@@ -25,9 +26,9 @@ class ArchivedTarget(object):
         self.essid_len = target.essid_len
 
     def transfer_info(self, other):
-        '''
+        """
             Helper function to transfer relevant fields into another Target or ArchivedTarget
-        '''
+        """
         other.attacked = self.attacked
 
         # If both targets know the essid, keep decloacked value
@@ -44,17 +45,16 @@ class ArchivedTarget(object):
 
     def __eq__(self, other):
         # Check if the other class type is either ArchivedTarget or Target
-        return (isinstance(other, self.__class__) or isinstance(other, Target)) \
-               and self.bssid == other.bssid
+        return isinstance(other, (self.__class__, Target)) and self.bssid == other.bssid
 
 
 class Target(object):
-    '''
+    """
         Holds details for a 'Target' aka Access Point (e.g. router).
-    '''
+    """
 
     def __init__(self, fields):
-        '''
+        """
             Initializes & stores target info based on fields.
             Args:
                 Fields - List of strings
@@ -74,17 +74,25 @@ class Target(object):
                     12 ID-length      (9)
                     13 ESSID          (HOME-ABCD)
                     14 Key            ()
-        '''
+        """
+        self.manufacturer = None
+        self.wps = WPSState.NONE
         self.bssid = fields[0].strip()
         self.channel = fields[3].strip()
         self.encryption = fields[5].strip()
         self.authentication = fields[7].strip()
-        if 'WPA' in self.encryption:
+
+        # airodump sometimes does not report the encryption type for some reason
+        # In this case (len = 0), defaults to WPA (which is the most common)
+        if 'WPA' in self.encryption or len(self.encryption) == 0:
             self.encryption = 'WPA'
         elif 'WEP' in self.encryption:
             self.encryption = 'WEP'
+        elif 'WPS' in self.encryption:
+            self.encryption = 'WPS'
+
         if len(self.encryption) > 4:
-            self.encryption = self.encryption[0:4].strip()
+            self.encryption = self.encryption[:4].strip()
 
         self.power = int(fields[8].strip())
         if self.power < 0:
@@ -104,7 +112,7 @@ class Target(object):
             self.essid = None  # '(%s)' % self.bssid
             self.essid_known = False
 
-        self.wps = WPSState.UNKNOWN
+        # self.wps = WPSState.UNKNOWN
 
         # Will be set to true once this target will be attacked
         # Needed to count targets in infinite attack mode
@@ -118,13 +126,12 @@ class Target(object):
 
     def __eq__(self, other):
         # Check if the other class type is either ArchivedTarget or Target
-        return (isinstance(other, self.__class__) or isinstance(other, ArchivedTarget)) \
-               and self.bssid == other.bssid
+        return isinstance(other, (self.__class__, ArchivedTarget)) and self.bssid == other.bssid
 
     def transfer_info(self, other):
-        '''
+        """
             Helper function to transfer relevant fields into another Target or ArchivedTarget
-        '''
+        """
         other.wps = self.wps
         other.attacked = self.attacked
 
@@ -141,7 +148,7 @@ class Target(object):
             other.essid_len = self.essid_len
 
     def validate(self):
-        ''' Checks that the target is valid. '''
+        """ Checks that the target is valid. """
         if self.channel == '-1':
             raise Exception('Ignoring target with Negative-One (-1) channel')
 
@@ -155,16 +162,17 @@ class Target(object):
             raise Exception('Ignoring target with Multicast BSSID (%s)' % self.bssid)
 
     def to_str(self, show_bssid=False, show_manufacturer=False):
-        '''
+        # sourcery no-metrics
+        """
             *Colored* string representation of this Target.
             Specifically formatted for the 'scanning' table view.
-        '''
+        """
 
         max_essid_len = 24
         essid = self.essid if self.essid_known else '(%s)' % self.bssid
         # Trim ESSID (router name) if needed
         if len(essid) > max_essid_len:
-            essid = essid[0:max_essid_len-3] + '...'
+            essid = essid[:max_essid_len - 3] + '...'
         else:
             essid = essid.rjust(max_essid_len)
 
@@ -175,18 +183,14 @@ class Target(object):
             # Unknown ESSID
             essid = Color.s('{O}%s' % essid)
 
-        if self.power < self.max_power:
-            max_power = self.max_power
+        # if self.power < self.max_power:
+        #     var = self.max_power
 
         # Add a '*' if we decloaked the ESSID
         decloaked_char = '*' if self.decloaked else ' '
         essid += Color.s('{P}%s' % decloaked_char)
 
-        if show_bssid:
-            bssid = Color.s('{O}%s  ' % self.bssid)
-        else:
-            bssid = ''
-
+        bssid = Color.s('{O}%s  ' % self.bssid) if show_bssid else ''
         if show_manufacturer:
             oui = ''.join(self.bssid.split(':')[:3])
             self.manufacturer = Configuration.manufacturers.get(oui, "")
@@ -195,16 +199,14 @@ class Target(object):
             manufacturer = Color.s('{W}%s  ' % self.manufacturer)
             # Trim manufacturer name if needed
             if len(manufacturer) > max_oui_len:
-                manufacturer = manufacturer[0:max_oui_len-3] + '...'
+                manufacturer = manufacturer[:max_oui_len - 3] + '...'
             else:
                 manufacturer = manufacturer.rjust(max_oui_len)
         else:
             manufacturer = ''
 
-        channel_color = '{G}'
-        if int(self.channel) > 14:
-            channel_color = '{C}'
-        channel = Color.s('%s%s' % (channel_color, str(self.channel).rjust(3)))
+        channel_color = '{C}' if int(self.channel) > 14 else '{G}'
+        channel = Color.s(f'{channel_color}{str(self.channel).rjust(3)}')
 
         encryption = self.encryption.rjust(3)
         if 'WEP' in encryption:
@@ -217,7 +219,7 @@ class Target(object):
             else:
                 encryption = Color.s('{O}%s  ' % encryption)
 
-        power = '%sdb' % str(self.power).rjust(3)
+        power = f'{str(self.power).rjust(3)}db'
         if self.power > 50:
             color = 'G'
         elif self.power > 35:
@@ -241,15 +243,16 @@ class Target(object):
         if len(self.clients) > 0:
             clients = Color.s('{G}  ' + str(len(self.clients)))
 
-        result = '%s  %s%s%s  %s  %s  %s  %s' % (
-                essid, bssid, manufacturer, channel, encryption, power, wps, clients)
+        result = f'{essid}  {bssid}{manufacturer}{channel}  {encryption}  {power}  {wps}  {clients}'
+
         result += Color.s('{W}')
         return result
 
 
 if __name__ == '__main__':
-    fields = 'AA:BB:CC:DD:EE:FF,2015-05-27 19:28:44,2015-05-27 19:28:46,1,54,WPA2,CCMP TKIP,PSK,-58,2,0,0.0.0.0,9,HOME-ABCD,'.split(',')
+    fields = 'AA:BB:CC:DD:EE:FF,2015-05-27 19:28:44,2015-05-27 19:28:46,1,54,WPA2,CCMP ' \
+             'TKIP,PSK,-58,2,0,0.0.0.0,9,HOME-ABCD,'.split(',')
     t = Target(fields)
     t.clients.append('asdf')
     t.clients.append('asdf')
-    print(t.to_str())
+    print((t.to_str()))
