@@ -8,7 +8,7 @@ from ..util.process import Process
 
 
 class Cowpatty(Dependency):
-    ''' Wrapper for Cowpatty program. '''
+    """ Wrapper for Cowpatty program. """
     dependency_required = False
     dependency_name = 'cowpatty'
     dependency_url = 'https://tools.kali.org/wireless-attacks/cowpatty'
@@ -27,10 +27,4 @@ class Cowpatty(Dependency):
         process = Process(command)
         stdout, stderr = process.get_output()
 
-        key = None
-        for line in stdout.split('\n'):
-            if 'The PSK is "' in line:
-                key = line.split('"', 1)[1][:-2]
-                break
-
-        return key
+        return next((line.split('"', 1)[1][:-2] for line in stdout.split('\n') if 'The PSK is "' in line), None)
