@@ -7,30 +7,25 @@ from .dependency import Dependency
 class Iw(Dependency):
     dependency_required = True
     dependency_name = 'iw'
-    dependency_url = 'apt-get install iw'
+    dependency_url = 'apt install iw'
 
     @classmethod
     def mode(cls, iface, mode_name):
         from ..util.process import Process
 
-        pid = None
         if mode_name == "monitor":
-            pid = Process(['iw', iface, 'set monitor control'])
+            return Process.call(f'iw {iface} set monitor control')
         else:
-            pid = Process(['iw', iface, 'type', mode_name])
-        pid.wait()
-
-        return pid.poll()
+            return Process.call(f'iw {iface} type {mode_name}')
 
     @classmethod
     def get_interfaces(cls, mode=None):
         from ..util.process import Process
         import re
 
-        ireg = re.compile(r"\s+Interface\s[a-zA-Z0-9]+")
+        ireg = re.compile(r"\s+Interface\s[a-zA-Z\d]+")
         mreg = re.compile(r"\s+type\s[a-zA-z]+")
         ires = None
-        mres = None
 
         interfaces = set()
         iface = ''
@@ -38,14 +33,13 @@ class Iw(Dependency):
         (out, err) = Process.call('iw dev')
         if mode is None:
             for line in out.split('\n'):
-                ires = ireg.search(line)
-                if ires:
+                if ires := ireg.search(line):
                     interfaces.add(ires.group().split("Interface")[-1])
         else:
+            mres = None
             for line in out.split('\n'):
                 ires = ireg.search(line)
-                mres = mreg.search(line)
-                if mres:
+                if mres := mreg.search(line):
                     if mode == mres.group().split("type")[-1][1:]:
                         interfaces.add(iface)
                 if ires:
