@@ -8,7 +8,7 @@ import re
 
 
 class Tshark(Dependency):
-    ''' Wrapper for Tshark program. '''
+    """ Wrapper for Tshark program. """
     dependency_required = False
     dependency_name = 'tshark'
     dependency_url = 'apt install wireshark'
@@ -35,7 +35,6 @@ class Tshark(Dependency):
 
         for line in output.split('\n'):
             src, dst, index, total = Tshark._extract_src_dst_index_total(line)
-
             if src is None:
                 continue  # Skip
 
@@ -59,7 +58,7 @@ class Tshark(Dependency):
                 # We know the BSSID and this msg was not for the target
                 continue
 
-            target_client_key = '%s,%s' % (target, client)
+            target_client_key = f'{target},{client}'
 
             # Ensure all 4 messages are:
             # Between the same client and target (not different clients connecting).
@@ -67,12 +66,10 @@ class Tshark(Dependency):
             if index == 1:
                 target_client_msg_nums[target_client_key] = 1  # First message
 
-            elif target_client_key not in target_client_msg_nums:
+            elif target_client_key not in target_client_msg_nums \
+                    or index - 1 != target_client_msg_nums[target_client_key]:
                 continue  # Not first message. We haven't gotten the first message yet. Skip.
 
-            elif index - 1 != target_client_msg_nums[target_client_key]:
-                continue  # Message is not in sequence. Skip
-
             else:
                 # Happy case: Message is > 1 and is received in-order
                 target_client_msg_nums[target_client_key] = index
@@ -109,7 +106,6 @@ class Tshark(Dependency):
     def bssid_essid_pairs(capfile, bssid):
         # Finds all BSSIDs (with corresponding ESSIDs) from cap file.
         # Returns list of tuples(BSSID, ESSID)
-
         if not Tshark.exists():
             return []
 
@@ -120,14 +116,15 @@ class Tshark(Dependency):
             '-r', capfile,  # Path to cap file
             '-n',  # Don't resolve addresses
             # Extract beacon frames
-            '-Y', '"wlan.fc.type_subtype == 0x08 || wlan.fc.type_subtype == 0x05"',
+            '-Y', 'wlan.fc.type_subtype == 0x08 || wlan.fc.type_subtype == 0x05',
         ]
+
         tshark = Process(command, devnull=False)
 
         for line in tshark.stdout().split('\n'):
             # Extract src, dst, and essid
             mac_regex = ('[a-zA-Z0-9]{2}:' * 6)[:-1]
-            match = re.search('(%s) [^ ]* (%s).*.*SSID=(.*)$' % (mac_regex, mac_regex), line)
+            match = re.search(f'({mac_regex}) [^ ]* ({mac_regex}).*.*SSID=(.*)$', line)
             if match is None:
                 continue  # Line doesn't contain src, dst, ssid
 
@@ -136,18 +133,14 @@ class Tshark(Dependency):
             if dst.lower() == 'ff:ff:ff:ff:ff:ff':
                 continue  # Skip broadcast packets
 
-            if bssid is not None:
-                # We know the BSSID, only return the ESSID for this BSSID.
-                if bssid.lower() == src.lower():
-                    ssid_pairs.add((src, essid))  # This is our BSSID, add it
-            else:
-                ssid_pairs.add((src, essid))  # We do not know BSSID, add it.
+            if (bssid is not None and bssid.lower() == src.lower()) or bssid is None:
+                ssid_pairs.add((src, essid))  # This is our BSSID, add it
 
         return list(ssid_pairs)
 
     @staticmethod
     def check_for_wps_and_update_targets(capfile, targets):
-        '''
+        """
             Given a cap file and list of targets, use TShark to
             find which BSSIDs in the cap file use WPS.
             Then update the 'wps' flag for those BSSIDs in the targets.
@@ -155,7 +148,7 @@ class Tshark(Dependency):
             Args:
                 capfile - .cap file from airodump containing packets
                 targets - list of Targets from scan, to be updated
-        '''
+        """
 
         if not Tshark.exists():
             raise ValueError('Cannot detect WPS networks: Tshark does not exist')
@@ -177,14 +170,9 @@ class Tshark(Dependency):
             p.wait()
             lines = p.stdout()
         except Exception as e:
-            # Manually check for keyboard interrupt as only python 3.x throws
-            # exceptions for subprocess.wait()
             if isinstance(e, KeyboardInterrupt):
-                raise KeyboardInterrupt
-
-            # Failure is acceptable
+                raise KeyboardInterrupt from e
             return
-
         wps_bssids = set()
         locked_bssids = set()
         for line in lines.split('\n'):
@@ -226,8 +214,7 @@ if __name__ == '__main__':
     # Should update 'wps' field of a target
     Tshark.check_for_wps_and_update_targets(test_file, targets)
 
-    print(('Target(BSSID={}).wps = {} (Expected: 1)'.format(
-        targets[0].bssid, targets[0].wps)))
+    print(f'Target(BSSID={targets[0].bssid}).wps = {targets[0].wps} (Expected: 1)')
     assert targets[0].wps == WPSState.UNLOCKED
 
     print((Tshark.bssids_with_handshakes(test_file, bssid=target_bssid)))
