@@ -1,29 +1,27 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from ..config import Configuration
-from ..model.handshake import Handshake
-from ..model.wpa_result import CrackResultWPA
-from ..model.pmkid_result import CrackResultPMKID
-from ..util.process import Process
-from ..util.color import Color
-from ..util.input import raw_input
-from ..tools.aircrack import Aircrack
-from ..tools.cowpatty import Cowpatty
-from ..tools.hashcat import Hashcat, HcxPcapTool
-from ..tools.john import John
-
+import os
 from json import loads
 
-import os
+from ..config import Configuration
+from ..model.handshake import Handshake
+from ..model.pmkid_result import CrackResultPMKID
+from ..model.wpa_result import CrackResultWPA
+from ..tools.aircrack import Aircrack
+from ..tools.cowpatty import Cowpatty
+from ..tools.hashcat import Hashcat, HcxPcapngTool
+from ..tools.john import John
+from ..util.color import Color
+from ..util.process import Process
+
 
 # TODO: Bring back the 'print' option, for easy copy/pasting. Just one-liners people can paste into terminal.
-
 # TODO: --no-crack option while attacking targets (implies user will run --crack later)
 
 
 class CrackHelper:
-    '''Manages handshake retrieval, selection, and running the cracking commands.'''
+    """Manages handshake retrieval, selection, and running the cracking commands."""
 
     TYPES = {
         '4-WAY': '4-Way Handshake',
@@ -33,8 +31,8 @@ class CrackHelper:
     # Tools for cracking & their dependencies. (RaduNico's code btw!)
     possible_tools = [
         ('aircrack', [Aircrack]),
-        ('hashcat', [Hashcat, HcxPcapTool]),
-        ('john', [John, HcxPcapTool]),
+        ('hashcat', [Hashcat, HcxPcapngTool]),
+        ('john', [John, HcxPcapngTool]),
         ('cowpatty', [Cowpatty])
     ]
 
@@ -45,7 +43,7 @@ class CrackHelper:
         # Get wordlist
         if not Configuration.wordlist:
             Color.p('\n{+} Enter wordlist file to use for cracking: {G}')
-            Configuration.wordlist = raw_input()
+            Configuration.wordlist = input()
             Color.p('{W}')
 
             if not os.path.exists(Configuration.wordlist):
@@ -60,22 +58,18 @@ class CrackHelper:
             return
 
         hs_to_crack = cls.get_user_selection(handshakes)
-        all_pmkid = all([hs['type'] == 'PMKID' for hs in hs_to_crack])
+        all_pmkid = all(hs['type'] == 'PMKID' for hs in hs_to_crack)
 
         # Identify missing tools
         missing_tools = []
         available_tools = []
         for tool, dependencies in cls.possible_tools:
-            missing = [
-                dep for dep in dependencies
-                if not Process.exists(dep.dependency_name)
-            ]
-            if len(missing) > 0:
+            if missing := [dep for dep in dependencies if not Process.exists(dep.dependency_name)]:
                 missing_tools.append((tool, missing))
             else:
                 available_tools.append(tool)
 
-        if len(missing_tools) > 0:
+        if missing_tools:
             Color.pl('\n{!} {O}Unavailable tools (install to enable):{W}')
             for tool, deps in missing_tools:
                 dep_list = ', '.join([dep.dependency_name for dep in deps])
@@ -87,7 +81,7 @@ class CrackHelper:
         else:
             Color.p('\n{+} Enter the {C}cracking tool{W} to use ({C}%s{W}): {G}' % (
                 '{W}, {C}'.join(available_tools)))
-            tool_name = raw_input()
+            tool_name = input()
             Color.p('{W}')
 
             if tool_name not in available_tools:
@@ -96,10 +90,9 @@ class CrackHelper:
 
         try:
             for hs in hs_to_crack:
-                if tool_name != 'hashcat' and hs['type'] == 'PMKID':
-                    if 'hashcat' in missing_tools:
-                        Color.pl('{!} {O}Hashcat is missing, therefore we cannot crack PMKID hash{W}')
-                        continue
+                if tool_name != 'hashcat' and hs['type'] == 'PMKID' and 'hashcat' in missing_tools:
+                    Color.pl('{!} {O}Hashcat is missing, therefore we cannot crack PMKID hash{W}')
+                    continue
                 cls.crack(hs, tool_name)
         except KeyboardInterrupt:
             Color.pl('\n{!} {O}Interrupted{W}')
@@ -113,7 +106,7 @@ class CrackHelper:
         if json is None:
             return False
         for result in json:
-            for k in result.keys():
+            for k in list(result.keys()):
                 v = result[k]
                 if 'file' in k and os.path.basename(v) == file:
                     return True
@@ -142,7 +135,7 @@ class CrackHelper:
             if hs_file.endswith('.cap'):
                 # WPA Handshake
                 hs_type = '4-WAY'
-            elif hs_file.endswith('.16800'):
+            elif hs_file.endswith('.22000'):
                 # PMKID hash
                 if not Process.exists('hashcat'):
                     skipped_pmkid_files += 1
@@ -155,18 +148,15 @@ class CrackHelper:
             date = date.rsplit('.', 1)[0]
             days, hours = date.split('T')
             hours = hours.replace('-', ':')
-            date = '%s %s' % (days, hours)
+            date = f'{days} {hours}'
 
-            # Patch for essid with " " (zero) or dot "." in name
-            handshakenew = Handshake(os.path.join(hs_dir, hs_file))
-            handshakenew.divine_bssid_and_essid()
-            essid_discovery = handshakenew.essid
-
-            if essid_discovery is None:
-                essid = essid
-            else:
-                essid = essid_discovery
+            if hs_type == '4-WAY':
+                # Patch for essid with " " (zero) or dot "." in name
+                handshakenew = Handshake(os.path.join(hs_dir, hs_file))
+                handshakenew.divine_bssid_and_essid()
+                essid_discovery = handshakenew.essid
 
+                essid = essid if essid_discovery is None else essid_discovery
             handshake = {
                 'filename': os.path.join(hs_dir, hs_file),
                 'bssid': bssid.replace('-', ':'),
@@ -178,7 +168,7 @@ class CrackHelper:
             if hs_file.endswith('.cap'):
                 # WPA Handshake
                 handshake['type'] = '4-WAY'
-            elif hs_file.endswith('.16800'):
+            elif hs_file.endswith('.22000'):
                 # PMKID hash
                 handshake['type'] = 'PMKID'
             else:
@@ -187,7 +177,8 @@ class CrackHelper:
             handshakes.append(handshake)
 
         if skipped_pmkid_files > 0:
-            Color.pl('{!} {O}Skipping %d {R}*.16800{O} files because {R}hashcat{O} is missing.{W}\n' % skipped_pmkid_files)
+            Color.pl(
+                '{!} {O}Skipping %d {R}*.22000{O} files because {R}hashcat{O} is missing.{W}\n' % skipped_pmkid_files)
         if skipped_cracked_files > 0:
             Color.pl('{!} {O}Skipping %d already cracked files.{W}\n' % skipped_cracked_files)
 
@@ -220,8 +211,10 @@ class CrackHelper:
     def get_user_selection(cls, handshakes):
         cls.print_handshakes(handshakes)
 
-        Color.p('{+} Select handshake(s) to crack ({G}%d{W}-{G}%d{W}, select multiple with {C},{W} or {C}-{W} or {C}all{W}): {G}' % (1, len(handshakes)))
-        choices = raw_input()
+        Color.p(
+            '{+} Select handshake(s) to crack ({G}%d{W}-{G}%d{W}, select multiple with '
+            '{C},{W} or {C}-{W} or {C}all{W}): {G}' % (1, len(handshakes)))
+        choices = input()
         Color.p('{W}')
 
         selection = []
@@ -229,13 +222,13 @@ class CrackHelper:
             if '-' in choice:
                 first, last = [int(x) for x in choice.split('-')]
                 for index in range(first, last + 1):
-                    selection.append(handshakes[index-1])
+                    selection.append(handshakes[index - 1])
             elif choice.strip().lower() == 'all':
                 selection = handshakes[:]
                 break
             elif [c.isdigit() for c in choice]:
                 index = int(choice)
-                selection.append(handshakes[index-1])
+                selection.append(handshakes[index - 1])
 
         return selection
 
@@ -249,7 +242,7 @@ class CrackHelper:
         elif hs['type'] == '4-WAY':
             crack_result = cls.crack_4way(hs, tool)
         else:
-            raise ValueError('Cannot crack handshake: Type is not PMKID or 4-WAY. Handshake=%s' % hs)
+            raise ValueError(f'Cannot crack handshake: Type is not PMKID or 4-WAY. Handshake={hs}')
 
         if crack_result is None:
             # Failed to crack
@@ -265,8 +258,8 @@ class CrackHelper:
     def crack_4way(cls, hs, tool):
 
         handshake = Handshake(hs['filename'],
-                bssid=hs['bssid'],
-                essid=hs['essid'])
+                              bssid=hs['bssid'],
+                              essid=hs['essid'])
         try:
             handshake.divine_bssid_and_essid()
         except ValueError as e:
